# DEV
# 0.0.5
- update `INSTALLED_APPS` to use `INSTALLED_APPS_REQUIRED`
- Update for dj-core 0.0.6
- Move package to top-level
# 0.0.4
- Update dependencies
# 0.0.3
- Fix typechecking on routes
- Add LICENSE
# 0.0.2
- Initial release
